@@ -3,5 +3,6 @@ test_that('searchrules', {
     d <- data.frame(a=1:n, b=n:1, c=runif(n))
     d <- lcut3(d)
 
-    #rules <- farules(d)
+    rules <- searchrules(d)
+    expect_true(is.farules(rules))
 })
